@@ -2,9 +2,12 @@
 
 ;;; Code:
 
+(autoload 'custom-add-loads "cus-load")
+
 (custom-add-loads 'extensions '("eldoc"))
 (custom-add-loads 'eldoc '("eldoc"))
 (custom-add-loads 'ielm '("ielm"))
+(custom-add-loads 'hide-copyleft '("hide-copyleft"))
 (custom-add-loads 'lisp '("elp" "find-func" "ielm"))
 (custom-add-loads 'elp '("elp"))
 (custom-add-loads 'find-function '("find-func"))
